/**
 * Created by yuany on 2017/7/19.
 */

const webpack = require('webpack')
const path = require("path");
const HtmlWebpackPlugin = require('html-webpack-plugin');
const theme = require('./package.json').theme;
const CopyWebpackPlugin = require('copy-webpack-plugin')


module.exports = {
    mode: "development",
    entry: "./src/index.js",
    output: {
        path: path.resolve(__dirname, 'dist'),
        filename: 'bundle-[hash:8].js'
    },
    plugins: [
        new HtmlWebpackPlugin({
            filename: 'index.html',
            template: './public/index.html'
        }),
        new CopyWebpackPlugin(["./public/authority.html"], {}),
        new webpack.HotModuleReplacementPlugin({}),
        new webpack.DefinePlugin({
            HOST: JSON.stringify('http://127.0.0.1/')
        })
    ],
    module: {
        rules: [
            {
                test: /\.js?$/,
                exclude: /(node_modules|bower_components)/,
                use: {
                    loader: 'babel-loader',
                    options:{
                        "presets": [
                            "es2015"
                        ],
                        "plugins": [
                            "syntax-jsx",
                            "transform-react-jsx",
                            "transform-es2015-spread",
                            "transform-react-display-name",
                            "transform-class-properties",
                            "transform-object-rest-spread",
                            "transform-es2015-template-literals",
                            [
                                "transform-runtime",
                                {
                                    "helpers": false,
                                    "polyfill": false,
                                    "regenerator": true,
                                    "moduleName": "babel-runtime"
                                }
                            ]
                        ]
                    }
                }
            },
            {
                test: /\.(less|css)$/,
                use: [
                    {loader: 'style-loader'},
                    {loader: 'css-loader'},
                    {loader: 'less-loader', options: {javascriptEnabled: true, modifyVars: theme}}
                ]
            },
            {
                test: /\.(png|jpg)$/,
                use: [
                    {loader: 'file-loader',},
                    {loader: 'url-loader', options: {limit: 1024}},
                ]
            }
        ]
    },
    resolve: {
        modules: ['node_modules', path.resolve(__dirname, './src')]
    },
    devServer: {
        contentBase: path.resolve(__dirname, 'dist'),
        compress: true,
        host: "0.0.0.0",
        port: 1212,
        hot: true,
    }
}